summaryrefslogtreecommitdiff
path: root/tools/qa/cppunit/test_rectangle.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'tools/qa/cppunit/test_rectangle.cxx')
-rw-r--r--tools/qa/cppunit/test_rectangle.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/tools/qa/cppunit/test_rectangle.cxx b/tools/qa/cppunit/test_rectangle.cxx
index 2b6518d797c4..4cf1b57d8b2b 100644
--- a/tools/qa/cppunit/test_rectangle.cxx
+++ b/tools/qa/cppunit/test_rectangle.cxx
@@ -32,8 +32,8 @@ void Test::test_rectangle()
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetWidth());
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetHeight());
- CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getWidth());
- CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getHeight());
+ CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getOpenWidth());
+ CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getOpenHeight());
}
{
@@ -47,10 +47,10 @@ void Test::test_rectangle()
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetWidth());
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetHeight());
// getWidth and getHeight return the size that excludes one of the bounds,
// unlike the ctor and GetWidth / GetHeight that operate on inclusive size
- CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getWidth());
- CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getHeight());
+ CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getOpenWidth());
+ CPPUNIT_ASSERT_EQUAL(tools::Long(0), aRect.getOpenHeight());
aRect.SetPosX(12);
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetHeight());
@@ -47,10 +47,10 @@ void Test::test_rectangle()
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetWidth());
CPPUNIT_ASSERT_EQUAL(tools::Long(1), aRect.GetHeight());
- // getWidth and getHeight return the size that excludes one of the bounds,
+ // getOpenWidth and getOpenHeight return the size that excludes one of the bounds,
// unlike the ctor and GetWidth / GetHeight that operate on inclusive size